@@ -1,6 +1,6 @@
 ;;; url-cache.el --- Uniform Resource Locator retrieval tool
 
-;; Copyright (C) 1996-1999, 2004-2012  Free Software Foundation, Inc.
+;; Copyright (C) 1996-1999, 2004-2017 Free Software Foundation, Inc.
 
 ;; Keywords: comm, data, processes, hypermedia
 
@@ -149,7 +149,6 @@ The actual return value is the last modification time of the cache file."
 (defun url-cache-create-filename-using-md5 (url)
   "Create a cached filename using MD5.
 Very fast if you have an `md5' primitive function, suitably fast otherwise."
-  (require 'md5)
   (if url
       (let* ((checksum (md5 url))
 	     (urlobj (url-generic-parse-url url))
@@ -213,7 +212,7 @@ If `url-standalone-mode' is non-nil, cached items never expire."
   "Remove all expired files from the cache.
 `url-cache-expire-time' says how old a file has to be to be
 considered \"expired\"."
-  (let ((current-time (current-time))
+  (let ((now (current-time))
 	(total-files 0)
 	(deleted-files 0))
     (setq directory (or directory url-cache-directory))
@@ -229,7 +228,7 @@ considered \"expired\"."
 	     (time-add
 	      (nth 5 (file-attributes file))
 	      (seconds-to-time url-cache-expire-time))
-	     current-time)
+	     now)
 	    (delete-file file)
 	    (setq deleted-files (1+ deleted-files))))))
       (if (< deleted-files total-files)
